@@ -1,5 +1,7 @@
 setClass("STS", # space-time partial 
-  representation("ST", index = "matrix"),
+  contains = "ST", 
+  #slots = c(index = "matrix"),
+  representation(index = "matrix"),
   validity = function(object) {
     stopifnot(ncol(object@index) == 2)
 	ix = unique(object@index[,1]) # space
@@ -11,7 +13,9 @@ setClass("STS", # space-time partial
 )
 
 setClass("STSDF", # space-time partial data frame
-  representation("STS", data = "data.frame"),
+  contains = "STS", 
+  #slots = c(data = "data.frame"),
+  representation(data = "data.frame"),
   validity = function(object) {
 	stopifnot(nrow(object@index) == nrow(object@data))
     #stopifnot(ncol(object@index) == 2)
